AnnotationSet

Struct AnnotationSet 

pub struct AnnotationSet { /* private fields */ }
A deterministic annotation collection.

Implementations

Source

impl AnnotationSet

pub const fn new() -> Self

Creates an empty annotation set.

pub fn insert(&mut self, annotation: Annotation) -> Option<AnnotationValue>

Inserts an annotation and returns the previous value for the key, if any.

pub fn insert_pair( &mut self, key: impl AsRef<str>, value: impl Into<AnnotationValue>, ) -> Result<Option<AnnotationValue>, AnnotationKeyError>

Inserts a key-value pair and returns the previous value for the key, if any.

Errors

Returns AnnotationKeyError::Empty when the key is empty.

pub fn get(&self, key: impl AsRef<str>) -> Option<&AnnotationValue>

Gets a value by key text.

pub fn remove(&mut self, key: impl AsRef<str>) -> Option<AnnotationValue>

Removes a value by key text.

pub fn iter(&self) -> impl Iterator<Item = (&AnnotationKey, &AnnotationValue)>

Iterates annotations in deterministic key order.

pub fn len(&self) -> usize

Returns the number of annotations.

pub fn is_empty(&self) -> bool

Returns true when the set has no annotations.