pub struct AnnotationSet { /* private fields */ }Expand description
A deterministic annotation collection.
Implementations
Sourceimpl AnnotationSet
impl AnnotationSet
Sourcepub fn insert(&mut self, annotation: Annotation) -> Option<AnnotationValue>
pub fn insert(&mut self, annotation: Annotation) -> Option<AnnotationValue>
Inserts an annotation and returns the previous value for the key, if any.
Sourcepub fn insert_pair(
&mut self,
key: impl AsRef<str>,
value: impl Into<AnnotationValue>,
) -> Result<Option<AnnotationValue>, AnnotationKeyError>
pub fn insert_pair( &mut self, key: impl AsRef<str>, value: impl Into<AnnotationValue>, ) -> Result<Option<AnnotationValue>, AnnotationKeyError>
Inserts a key-value pair and returns the previous value for the key, if any.
Errors
Returns AnnotationKeyError::Empty when the key is empty.
Sourcepub fn remove(&mut self, key: impl AsRef<str>) -> Option<AnnotationValue>
pub fn remove(&mut self, key: impl AsRef<str>) -> Option<AnnotationValue>
Removes a value by key text.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&AnnotationKey, &AnnotationValue)>
pub fn iter(&self) -> impl Iterator<Item = (&AnnotationKey, &AnnotationValue)>
Iterates annotations in deterministic key order.